summaryrefslogtreecommitdiff
path: root/linux-user
diff options
context:
space:
mode:
authorths <ths@c046a42c-6fe2-441c-8c8c-71466251a162>2007-06-03 13:35:16 +0000
committerths <ths@c046a42c-6fe2-441c-8c8c-71466251a162>2007-06-03 13:35:16 +0000
commite91c8a778349982eb49fd319ab6506911e2d837e (patch)
tree4c12e093e72dc6147139463d31fba275f2e6dd03 /linux-user
parent6d9db39cd9c31084ab782f6ffd2d67e606fb0802 (diff)
downloadqemu-e91c8a778349982eb49fd319ab6506911e2d837e.tar.gz
Spelling fixes, by Stefan Weil.
git-svn-id: svn://svn.savannah.nongnu.org/qemu/trunk@2927 c046a42c-6fe2-441c-8c8c-71466251a162
Diffstat (limited to 'linux-user')
-rw-r--r--linux-user/elfload.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/linux-user/elfload.c b/linux-user/elfload.c
index c1306929cb..c0845fe650 100644
--- a/linux-user/elfload.c
+++ b/linux-user/elfload.c
@@ -799,7 +799,7 @@ static unsigned long load_elf_interp(struct elfhdr * interp_elf_ex,
#endif
if (interp_elf_ex->e_type == ET_DYN) {
/* in order to avoid harcoding the interpreter load
address in qemu, we allocate a big enough memory zone */
error = target_mmap(0, INTERP_MAP_SIZE,
PROT_NONE, MAP_PRIVATE | MAP_ANON,
@@ -1191,7 +1191,7 @@ int load_elf_binary(struct linux_binprm * bprm, struct target_pt_regs * regs,
base, as well as whatever program they might try to exec. This
is because the brk will follow the loader, and is not movable. */
/* NOTE: for qemu, we do a big mmap to get enough space
- without harcoding any address */
+ without hardcoding any address */
error = target_mmap(0, ET_DYN_MAP_SIZE,
PROT_NONE, MAP_PRIVATE | MAP_ANON,
-1, 0);
@@ -799,7 +799,7 @@ static unsigned long load_elf_interp(struct elfhdr * interp_elf_ex,
#endif
if (interp_elf_ex->e_type == ET_DYN) {
- /* in order to avoid harcoding the interpreter load
+ /* in order to avoid hardcoding the interpreter load
address in qemu, we allocate a big enough memory zone */
error = target_mmap(0, INTERP_MAP_SIZE,